@@ -44,7 +44,7 @@ from update_checker import update_check
 from warnings import warn_explicit
 
 
-__version__ = '2.1.12'
+__version__ = '2.1.13'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -70,6 +70,7 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
                  'approve':             'api/approve/',
                  'authorize':           'api/v1/authorize/',
                  'banned':              'r/%s/about/banned/',
+                 'blocked':             'prefs/blocked/',
                  'by_id':               'by_id/',
                  'captcha':             'captcha/',
                  'clearflairtemplates': 'api/clearflairtemplates/',
@@ -211,7 +212,7 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
         self.client_id = obj.get('oauth_client_id') or None
         self.client_secret = obj.get('oauth_client_secret') or None
         self.redirect_uri = obj.get('oauth_redirect_uri') or None
-        self.store_json_result = obj.get('store_json_result') or None
+        self.store_json_result = config_boolean(obj.get('store_json_result'))
 
         if 'short_domain' in obj:
             self._short_domain = 'http://' + obj['short_domain']
@@ -869,7 +870,7 @@ class UnauthenticatedReddit(BaseReddit):
         return self.get_content(self.config['rising'], *args, **kwargs)
 
     def get_submission(self, url=None, submission_id=None, comment_limit=0,
-                       comment_sort=None):
+                       comment_sort=None, params={}):
         """Return a Submission object for the given url or submission_id.
 
         :param comment_limit: The desired number of comments to fetch. If <= 0
@@ -877,6 +878,7 @@ class UnauthenticatedReddit(BaseReddit):
             maximum possible.
         :param comment_sort: The sort order for retrieved comments. When None
             use the default for the session's user.
+        :param params: Dictionary containing extra GET data to put in the url.
 
         """
         if bool(url) == bool(submission_id):
@@ -885,7 +887,8 @@ class UnauthenticatedReddit(BaseReddit):
             url = urljoin(self.config['comments'], submission_id)
         return objects.Submission.from_url(self, url,
                                            comment_limit=comment_limit,
-                                           comment_sort=comment_sort)
+                                           comment_sort=comment_sort,
+                                           params=params)
 
     def get_submissions(self, fullnames, *args, **kwargs):
         """Generate Submission objects for each item provided in `fullnames`.
@@ -1533,7 +1536,7 @@ class ModFlairMixin(AuthenticatedReddit):
                 'name': six.text_type(user)}
         return self.request_json(self.config['deleteflair'], data=data)
 
-    @decorators.restrict_access(scope='modflair', mod=False, login=False)
+    @decorators.restrict_access(scope='modflair')
     def get_flair_list(self, subreddit, *args, **kwargs):
         """Return a get_content generator of flair mappings.
 
@@ -1646,15 +1649,24 @@ class ModOnlyMixin(AuthenticatedReddit):
 
     """
 
-    @decorators.restrict_access(scope=None, mod=True)
-    def get_banned(self, subreddit):
-        """Return the list of banned users for the given subreddit."""
-        return self.request_json(self.config['banned'] %
-                                 six.text_type(subreddit))
+    def _get_userlist_listing(self, url, *args, **kwargs):
+        content = self.get_content(url, *args, **kwargs)
+        for data in content:
+            user = objects.Redditor(self, data['name'], fetch=False)
+            # pylint: disable-msg=C0103,W0201
+            user.id = data['id'].split('_')[1]
+            yield user
 
-    def get_contributors(self, subreddit):
+    @decorators.restrict_access(scope=None, mod=True)
+    def get_banned(self, subreddit, *args, **kwargs):
+        """Return a get_content generator of banned users for the subreddit."""
+        return self._get_userlist_listing(self.config['banned'] %
+                                          six.text_type(subreddit),
+                                          *args, **kwargs)
+
+    def get_contributors(self, subreddit, *args, **kwargs):
         """
-        Return the list of contributors for the given subreddit.
+        Return a get_content generator of contributors for the given subreddit.
 
         If it's a public subreddit, then user/pswd authentication as a
         moderator of the subreddit is required. For protected/private
@@ -1666,8 +1678,9 @@ class ModOnlyMixin(AuthenticatedReddit):
             # It is necessary to have the 'self' argument as it's needed in
             # restrict_access to determine what class the decorator is
             # operating on.
-            return self.request_json(self.config['contributors'] %
-                                     six.text_type(subreddit))
+            return self._get_userlist_listing(self.config['contributors'] %
+                                              six.text_type(subreddit),
+                                              *args, **kwargs)
 
         if self.is_logged_in():
             if not isinstance(subreddit, objects.Subreddit):
@@ -1761,16 +1774,25 @@ class ModOnlyMixin(AuthenticatedReddit):
                                 six.text_type(subreddit), *args, **kwargs)
 
     @decorators.restrict_access(scope=None, mod=True)
-    def get_wiki_banned(self, subreddit):
-        """Return a list of users banned from the wiki."""
-        return self.request_json(self.config['wiki_banned'] %
-                                 six.text_type(subreddit))
+    def get_wiki_banned(self, subreddit, *args, **kwargs):
+        """Return a get_content generator of users banned from the wiki."""
+        return self._get_userlist_listing(self.config['wiki_banned'] %
+                                          six.text_type(subreddit),
+                                          *args, **kwargs)
 
     @decorators.restrict_access(scope=None, mod=True)
-    def get_wiki_contributors(self, subreddit):
-        """Return a list of users who can contribute to the wiki."""
-        return self.request_json(self.config['wiki_contributors'] %
-                                 six.text_type(subreddit))
+    def get_wiki_contributors(self, subreddit, *args, **kwargs):
+        """Return a get_content generator of wiki contributors.
+
+        The returned users are those who have been approved as a wiki
+        contributor by the moderators of the subreddit, Whether or not they've
+        actually contributed to the wiki is irrellevant, their approval as wiki
+        contributors is all that matters.
+
+        """
+        return self._get_userlist_listing(self.config['wiki_contributors'] %
+                                          six.text_type(subreddit),
+                                          *args, **kwargs)
 
 
 class MySubredditsMixin(AuthenticatedReddit):
