@@ -23,6 +23,7 @@ that it can be saved and unsaved in the context of a logged in user.
 """
 
 import six
+from six.moves.urllib.parse import parse_qs, urlparse, urlunparse
 from heapq import heappop, heappush
 from requests.compat import urljoin
 from praw import (AuthenticatedReddit as AR, ModConfigMixin as MCMix,
@@ -747,8 +748,8 @@ class LoggedInRedditor(Redditor):
 
     def get_blocked(self):
         """Return a UserList of Redditors with whom the user has blocked."""
-        url = self.reddit_session.config['friends']
-        return self.reddit_session.request_json(url)[1]
+        url = self.reddit_session.config['blocked']
+        return self.reddit_session.request_json(url)
 
     def get_cached_moderated_reddits(self):
         """Return a cached dictionary of the user's moderated reddits.
@@ -818,7 +819,7 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
     @staticmethod
     @restrict_access(scope='read')
     def from_url(reddit_session, url, comment_limit=0, comment_sort=None,
-                 comments_only=False):
+                 comments_only=False, params={}):
         """Request the url and return a Submission object.
 
         :param reddit_session: The session to make the request with.
@@ -829,9 +830,13 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         :param comment_sort: The sort order for retrieved comments. When None
             use the default for the session's user.
         :param comments_only: Return only the list of comments.
+        :param params: dictionary containing extra GET data to put in the url.
 
         """
-        params = {}
+        query_pairs = parse_qs(urlparse(url).query)
+        get_params = dict((k, ",".join(v)) for k, v in query_pairs.items())
+        params.update(get_params)
+        url = urlunparse(urlparse(url)[:3] + ("", "", ""))
         if comment_limit is None:  # Fetch MAX
             params['limit'] = 2048  # Just use a big number
         elif comment_limit > 0:  # Use value
